summaryrefslogtreecommitdiff
path: root/core/pim/addressbook/abtable.cpp
Side-by-side diff
Diffstat (limited to 'core/pim/addressbook/abtable.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--core/pim/addressbook/abtable.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/core/pim/addressbook/abtable.cpp b/core/pim/addressbook/abtable.cpp
index 3fb2214..30d749c 100644
--- a/core/pim/addressbook/abtable.cpp
+++ b/core/pim/addressbook/abtable.cpp
@@ -118,21 +118,21 @@ AbTable::AbTable( const QValueList<int> order, QWidget *parent, const char *name
asc( TRUE ),
intFields( order ),
enablePainting( true ),
columnVisible( true ),
countNested( 0 )
{
- // owarn << "C'tor start" << oendl;
+ // odebug << "C'tor start" << oendl;
setSelectionMode( NoSelection );
init();
setSorting( TRUE );
connect( this, SIGNAL(clicked(int,int,int,const QPoint&)),
this, SLOT(itemClicked(int,int)) );
// contactList.clear();
- // owarn << "C'tor end" << oendl;
+ // odebug << "C'tor end" << oendl;
}
AbTable::~AbTable()
{
}
@@ -148,13 +148,13 @@ void AbTable::init()
verticalHeader()->hide();
columnVisible = true;
}
void AbTable::setContacts( const Opie::OPimContactAccess::List& viewList )
{
- owarn << "AbTable::setContacts()" << oendl;
+ odebug << "AbTable::setContacts()" << oendl;
clear();
m_viewList = viewList;
setSorting( false );
setPaintingEnabled( FALSE );
@@ -180,28 +180,28 @@ void AbTable::setOrderedList( const QValueList<int> ordered )
intFields = ordered;
}
bool AbTable::selectContact( int UID )
{
- owarn << "AbTable::selectContact( " << UID << " )" << oendl;
+ odebug << "AbTable::selectContact( " << UID << " )" << oendl;
int rows = numRows();
Opie::OPimContact* foundContact = 0l;
bool found = false;
setPaintingEnabled( FALSE );
- owarn << "Search start" << oendl;
+ odebug << "Search start" << oendl;
for ( int r = 0; r < rows; ++r ) {
if ( m_viewList.uidAt( r ) == UID ){
ensureCellVisible( r, 0 );
setCurrentCell( r, 0 );
found = true;
break;
}
}
- owarn << "Search end" << oendl;
+ odebug << "Search end" << oendl;
if ( !found ){
ensureCellVisible( 0,0 );
setCurrentCell( 0, 0 );
}
@@ -210,13 +210,13 @@ bool AbTable::selectContact( int UID )
return true;
}
#if 0
void AbTable::insertIntoTable( const Opie::OPimContact& cnt, int row )
{
- owarn << "void AbTable::insertIntoTable( const Opie::OPimContact& cnt, "
+ odebug << "void AbTable::insertIntoTable( const Opie::OPimContact& cnt, "
<< row << " )" << oendl;
QString strName;
ContactItem contactItem;
strName = findContactName( cnt );
contactItem = findContactContact( cnt, row );
@@ -280,13 +280,13 @@ int AbTable::currentEntry_UID()
{
return ( currentEntry().uid() );
}
void AbTable::clear()
{
- owarn << "void AbTable::clear()" << oendl;
+ odebug << "void AbTable::clear()" << oendl;
// contactList.clear();
setPaintingEnabled( FALSE );
for ( int r = 0; r < numRows(); ++r ) {
for ( int c = 0; c < numCols(); ++c ) {
if ( cellWidget( r, c ) )
@@ -331,36 +331,36 @@ void AbTable::keyPressEvent( QKeyEvent *e )
{
char key = toupper( e->ascii() );
if ( key >= 'A' && key <= 'Z' )
moveTo( key );
- // owarn << "Received key .." << oendl;
+ // odebug << "Received key .." << oendl;
switch( e->key() ) {
case Qt::Key_Space:
case Qt::Key_Return:
case Qt::Key_Enter:
emit signalSwitch();
break;
// case Qt::Key_Up:
-// owarn << "a" << oendl;
+// odebug << "a" << oendl;
// emit signalKeyUp();
// break;
// case Qt::Key_Down:
-// owarn << "b" << oendl;
+// odebug << "b" << oendl;
// emit signalKeyDown();
// break;
default:
QTable::keyPressEvent( e );
}
}
void AbTable::moveTo( char c )
{
- owarn << "void AbTable::moveTo( char c ) NOT IMPLEMENTED !!" << oendl;
+ odebug << "void AbTable::moveTo( char c ) NOT IMPLEMENTED !!" << oendl;
#if 0
int rows = numRows();
QString value;
AbTableItem *abi;
int r;
@@ -420,13 +420,13 @@ void AbTable::resizeRows() {
*/
}
void AbTable::realignTable()
{
- // owarn << "void AbTable::realignTable()" << oendl;
+ // odebug << "void AbTable::realignTable()" << oendl;
setPaintingEnabled( FALSE );
resizeRows();
fitColumns();
@@ -470,37 +470,37 @@ void QTable::paintEmptyArea( QPainter *p, int cx, int cy, int cw, int ch )
// }
void AbTable::fitColumns()
{
- owarn << "void AbTable::fitColumns()" << oendl;
+ odebug << "void AbTable::fitColumns()" << oendl;
int contentsWidth = visibleWidth() / 2;
// Fix to better value
// contentsWidth = 130;
setPaintingEnabled( FALSE );
if ( columnVisible == false ){
showColumn(0);
columnVisible = true;
}
- // owarn << "Width: " << contentsWidth << oendl;
+ // odebug << "Width: " << contentsWidth << oendl;
setColumnWidth( 0, contentsWidth );
adjustColumn(1);
if ( columnWidth(1) < contentsWidth )
setColumnWidth( 1, contentsWidth );
setPaintingEnabled( TRUE );
}
void AbTable::show()
{
- // owarn << "void AbTable::show()" << oendl;
+ // odebug << "void AbTable::show()" << oendl;
realignTable();
QTable::show();
}
#if 0
void AbTable::setChoiceNames( const QStringList& list)
@@ -518,17 +518,17 @@ void AbTable::setChoiceNames( const QStringList& list)
fitColumns();
}
#endif
void AbTable::itemClicked(int,int col)
{
- // owarn << "AbTable::itemClicked(int, col: " << col << ")" << oendl;
+ // odebug << "AbTable::itemClicked(int, col: " << col << ")" << oendl;
if ( col == 2 ) {
return;
} else {
- // owarn << "Emitting signalSwitch()" << oendl;
+ // odebug << "Emitting signalSwitch()" << oendl;
emit signalSwitch();
}
}
#if 0
QStringList AbTable::choiceNames() const
@@ -559,13 +559,13 @@ QStringList AbTable::choiceSelection(int /*index*/) const
return r;
}
void AbTable::updateVisible()
{
- // owarn << "void AbTable::updateVisible()" << oendl;
+ // odebug << "void AbTable::updateVisible()" << oendl;
int visible,
totalRows,
row,
selectedRow = 0;
@@ -595,13 +595,13 @@ void AbTable::updateVisible()
setPaintingEnabled( TRUE );
}
void AbTable::setPaintingEnabled( bool e )
{
// owarn << "IN void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
if ( e ) {
if ( countNested > 0 )
--countNested;
if ( ! countNested ){
@@ -612,29 +612,29 @@ void AbTable::setPaintingEnabled( bool e )
}
} else {
++countNested;
enablePainting = false;
setUpdatesEnabled( false );
}
// owarn << "OUT void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
}
void AbTable::viewportPaintEvent( QPaintEvent* e ) {
- // owarn << "void AbTable::viewportPaintEvent( QPaintEvent* e ) -> "
+ // odebug << "void AbTable::viewportPaintEvent( QPaintEvent* e ) -> "
// << enablePainting << oendl;
if ( enablePainting )
QTable::viewportPaintEvent( e );
}
void AbTable::paintCell(QPainter* p, int row, int col, const QRect& cr, bool ) {
const QColorGroup &cg = colorGroup();
p->save();
- // owarn << "Paint row: " << row << oendl;
+ // odebug << "Paint row: " << row << oendl;
Opie::OPimContact act_contact = m_viewList[row];
// Paint alternating background bars
if ( (row % 2 ) == 0 ) {
@@ -595,13 +595,13 @@ void AbTable::updateVisible()
void AbTable::setPaintingEnabled( bool e )
{
- // owarn << "IN void AbTable::setPaintingEnabled( " << e << " )->Nested: "
+ // odebug << "IN void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
if ( e ) {
@@ -612,29 +612,29 @@ void AbTable::setPaintingEnabled( bool e )
setUpdatesEnabled( false );
}
- // owarn << "OUT void AbTable::setPaintingEnabled( " << e << " )->Nested: "
+ // odebug << "OUT void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
}
p->fillRect( 0, 0, cr.width(), cr.height(), cg.brush( QColorGroup::Base ) );